use strict;
use warnings;

# Corrects single file.
#
sub correct_file($)
{
	my ($file_name) = @_;
	open INPUT, "<$file_name";
	my @lines = (<INPUT>);
	close INPUT;

	my $changed = 0;
	for (my $i = 0; $i < scalar(@lines); ++$i) {
		my ($prefix, $value, $suffix) = $lines[$i] =~ /(\s*hide_in:\s*0x)([A-Fa-f0-9]+)(\s*)/;
		next unless defined $value;

		# Filter out now unused multi-monitor bits.

		my $original_mask = hex($value);
		my $new_mask = $original_mask & 0x201FFFF9;
		if ($new_mask == $original_mask) {
			return
		}	
                $changed = 1;
                $lines[$i] = sprintf("%s%08X%s", $prefix, $new_mask, $suffix);
	}

	# Write the new content if there was any change.

	return unless $changed;

	print "Updated $file_name\n";

	open OUTPUT, ">$file_name";
	print OUTPUT join("", @lines);
	close OUTPUT;
}

# Corrects single folder in the hierarchy.
#
sub correct_folder
{
	my ($path) = @_;
	opendir(my $dir, $path);
	while (my $entry = readdir($dir)) {
		my $combined_path = "$path/$entry";
		if ((-f $combined_path) && ($entry =~ /\.sii$/)) {
			correct_file($combined_path);
		}
		elsif ((-d $combined_path) && ($entry =~ /\w+/)) {
			correct_folder($combined_path);
		}
	}
	closedir($dir);
}

correct_folder(".");

# eof #
